#!/usr/bin/env python
# vim: set ts=4 sts=4 sw=4 textwidth=92 :

import os, sys, unittest
from rarslave import *

class rarslavetest (unittest.TestCase):
	def setUp (self):
		pass

	def tearDown (self):
		pass

	def testGetBasenameNone (self):
		QNAME = '[something] some names.txt'
		ANAME = '[something] some names.txt'

		# Tests for an exension that should not be stripped
		self.assertEquals (ANAME, get_basename (QNAME))

	def testGetBasenameSingle (self):
		QNAME = '[something] some names.par2'
		ANAME = '[something] some names'

		self.assertEquals (ANAME, get_basename (QNAME))

	def testGetBasenameMulti (self):
		QNAME = '[a.f.k.] The Melancholy of Haruhi Suzumiya - 13.avi.001'
		ANAME = '[a.f.k.] The Melancholy of Haruhi Suzumiya - 13'

		self.assertEquals (ANAME, get_basename (QNAME))

	def testGetBasenameMulti2 (self):
		QNAME = '[AonE-AnY]_Ah_My_Goddess_-_Sorezore_no_Tsubasa_-_13_[WS][E6380C3F].avi.vol00+01.PAR2'
		ANAME = '[AonE-AnY]_Ah_My_Goddess_-_Sorezore_no_Tsubasa_-_13_[WS][E6380C3F]'

		self.assertEquals (ANAME, get_basename (QNAME))

	def testFindLikelyFilesBadDir (self):
		DIR = '/fake/dir'
		
		self.assertRaises (ValueError, find_likely_files, "fake", DIR)

	def testFindAllPar2Files (self):
		DIR = '/fake/dir'

		self.assertRaises (ValueError, find_all_par2_files, DIR)

	def testHasExtension1 (self):
		FILE = 'some.file.part01.rar'

		self.assertTrue (has_extension (FILE, 'rar'))
		self.assertTrue (has_extension (FILE, '.rar'))
		self.assertTrue (has_extension (FILE, 'part01.rar'))
		self.assertTrue (has_extension (FILE, '.part01.rar'))

	def testHasExtension2 (self):
		FILE = 'some.file.part01.rar'

		self.assertFalse (has_extension (FILE, 'zip'))
		self.assertFalse (has_extension (FILE, '.zip'))
		self.assertFalse (has_extension (FILE, '.part01'))
		self.assertFalse (has_extension (FILE, 'part01'))


if __name__ == '__main__':
	unittest.main ()

